<?php

function ryoumou_trade_agent_menu() {
    add_menu_page(
        'Ryoumou Trade Agent', 
        '両毛トレードエージェント', 
        'manage_options', 
        'ryoumou-trade-agent', 
        'ryoumou_trade_agent_page'
    );
}
add_action('admin_menu', 'ryoumou_trade_agent_menu');

function ryoumou_trade_agent_page() {
    if (isset($_POST['submit'])) {
        // 20件の文言を保存
        $phrases = array_filter(array_map('wp_kses_post', $_POST['phrases']));
        if (count($phrases) <= 20) {
            update_option('random_phrases_list', $phrases);
            echo '<div class="updated"><p>Saved successfully.</p></div>';
        } else {
            echo '<div class="error"><p>Maximum 20 phrases allowed.</p></div>';
        }

        // URLと文言のセットを保存
        $url_sets = array();
        for ($i = 0; $i < 3; $i++) {
            $url = sanitize_text_field($_POST['urls'][$i]);
            $text = wp_kses_post($_POST['texts'][$i]);
            if (!empty($url) && !empty($text)) {
                $url_sets[] = array('url' => $url, 'text' => $text);
            }
        }
        update_option('custom_url_text_sets', $url_sets);

        // カスタムCSSを保存
        $custom_css = sanitize_textarea_field($_POST['custom_css']);
        update_option('ryoumou_trade_agent_custom_css', $custom_css);
    }

    // 保存された文言、URLセット、カスタムCSSを取得
    $phrases = get_option('random_phrases_list', array());
    $url_sets = get_option('custom_url_text_sets', array());
    $custom_css = get_option('ryoumou_trade_agent_custom_css', '');

    ?>
    <div class="wrap">
        <h1>Ryoumou Trade Agent</h1>
        
        <!-- ランダム表示機能の説明 -->
        <h2>ランダム表示機能</h2>
        <p>登録した文字列1～20がランダムで表示されます。広告をランダムで表示する場合に便利です。</p>
        <p><strong>ショートコード:</strong> <code>[RM-random_phrase]</code></p>
        
        <!-- フォームのランダム表示部分 -->
        <form method="POST">
            <?php for ($i = 0; $i < 20; $i++): ?>
                <p>
                    <label for="phrase_<?php echo $i; ?>">Phrase <?php echo $i + 1; ?>:</label>
                    
					<!-- code 2024/12/2 -->
<textarea name="phrases[]" id="phrase_<?php echo $i; ?>" rows="4" style="width: 80%;">
<?php echo stripslashes(htmlspecialchars_decode($phrases[$i] ?? '', ENT_QUOTES)); ?>
</textarea>
                </p>
            <?php endfor; ?>

            <!-- URL指定表示機能の説明 -->
            <h2>URL指定表示機能</h2>
            <p>指定したURLのみに、指定した文字列が表示されます。例えばTOPページのみに表示したい場合は、URLにTOPのURLを設定し、ブログの紹介文などを設定することができます。</p>
            <p><strong>ショートコード:</strong> <code>[RM-print_agent]</code></p>

            <!-- URLと文言を入力するフィールド -->
            <?php for ($i = 0; $i < 3; $i++): ?>
                <p>
                    <label for="url_<?php echo $i; ?>">URL <?php echo $i + 1; ?>:</label>
                    <input type="text" name="urls[]" id="url_<?php echo $i; ?>" value="<?php echo esc_url($url_sets[$i]['url'] ?? ''); ?>" style="width: 80%;">
                </p>
                <p>
                    <label for="text_<?php echo $i; ?>">Text <?php echo $i + 1; ?>:</label>
                    <textarea name="texts[]" id="text_<?php echo $i; ?>" rows="4" style="width: 80%;"><?php echo esc_textarea($url_sets[$i]['text'] ?? ''); ?></textarea>
                </p>
            <?php endfor; ?>

            <!-- カスタムCSS入力フィールド -->
            <h2>カスタムCSS</h2>
            <p>以下にCSSコードを入力してください。このCSSはフロントエンドに適用されます。</p>
            <textarea name="custom_css" rows="10" style="width: 80%;"><?php echo esc_textarea($custom_css); ?></textarea>
            
            <p>
                <input type="submit" name="submit" class="button-primary" value="Save Settings">
            </p>
        </form>

        <!-- ショートコードの使用方法の説明 -->
        <h2>ショートコードの使用方法</h2>
        <p><strong>[RM-random_phrase]</strong>: 登録されたランダムな文言を表示します。</p>
        <p><strong>[RM-custom_sitemap]</strong>: カスタムサイトマップを表示します。</p>
        <p><strong>[RM-check_videos]</strong>: 各記事の動画リンクの件数を一括で抽出し表示します。</p>
        <p><strong>[RM-images_without_alt]</strong>: 画像のalt属性が未設定の画像を抽出します。</p>
        <p><strong>[RM-check_blog_links]</strong>: 各記事の被リンクを表示します。</p>

    </div>
    <?php
}
?>
